<!-- markdownlint-disable -->

<a href="..\..\qtstrap\extras\log_monitor\log_profile.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `extras.log_monitor.log_profile`




**Global Variables**
---------------
- **session_start_time**
- **default_columns**


---

<a href="..\..\qtstrap\extras\log_monitor\log_profile.py#L7"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `Column`




<a href="..\..\qtstrap\extras\log_monitor\log_profile.py#L8"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `Column.__init__`

```python
__init__(name=None, title=None, visible=True, width=50)
```








---

<a href="..\..\qtstrap\extras\log_monitor\log_profile.py#L14"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `Column.set_visibility`

```python
set_visibility(visible)
```






---

<a href="..\..\qtstrap\extras\log_monitor\log_profile.py#L35"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `LogProfile`




<a href="..\..\qtstrap\extras\log_monitor\log_profile.py#L36"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogProfile.__init__`

```python
__init__()
```






---

#### <kbd>property</kbd> LogProfile.visible_columns







---

<a href="..\..\qtstrap\extras\log_monitor\log_profile.py#L61"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogProfile.build_query`

```python
build_query()
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_profile.py#L51"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogProfile.get_log_level_column`

```python
get_log_level_column()
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_profile.py#L54"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogProfile.set_filter`

```python
set_filter(filt)
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
